@@ -13,7 +13,7 @@ import collections
 # Add local package dir to path
 sys.path.insert(0, os.path.abspath("../src"))
 
-from mini_buildd import __version__, PyCompat, django_settings, config, api   # noqa (pep8 E402)
+from mini_buildd import config, util, api, django_settings   # noqa (pep8 E402)
 
 # Pseudo-configure django
 django_settings.pseudo_configure()
@@ -51,9 +51,8 @@ def pysources():
 #: list of tuples: [(file_path, file_hr_id)]
 for gen in [
         [pathlib.Path(".").rglob("*.rst"), lambda fn: os.path.splitext(fn)[0]],
-        # "../src/mini_buildd/models/base.py" -> "mini_buildd.models.base"
-        [pysources(), lambda fn: "python/" + os.path.splitext(PyCompat.removeprefix(str(fn), "../src/"))[0].replace("/", ".").replace(".__init__", "")],
-        # "../src/mini_buildd/models/base.py" -> "mini_buildd.models.base"
+        # "../src/mini_buildd/<module>.py" -> "mini_buildd.<module>"
+        [pysources(), lambda fn: "python/" + os.path.splitext(util.PyCompat.removeprefix(str(fn), "../src/"))[0].replace("/", ".").replace(".__init__", "")],
         [pathlib.Path("../src/mini_buildd/templates/").rglob("*.html"), lambda fn: "/".join(fn.parts[3:])],
 ]:
     for f_name in gen[0]:
@@ -87,9 +86,9 @@ admonitions: *{", ".join(ADMONITIONS)}*.
 
 # Project data
 project = "mini-buildd"
-copyright = "2012-2022, mini-buildd maintainers"
-version = __version__
-release = __version__
+copyright = "2012-2023, mini-buildd maintainers"
+version = util.__version__
+release = util.__version__
 
 # Config
 extensions = [
