@@ -5,6 +5,7 @@ import os
 import sys
 import inspect
 import collections
+import enum
 import logging
 import argparse
 import re
@@ -1336,7 +1337,57 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
 
         yield ListArgument(["--remotes"], default=[], doc=f"Remotes to add. {inspect.getdoc(net.ClientEndpoint)}", header="Remotes")
 
+    class Report(dict):
+        SEVERITY_MESSAGES = {
+            None: "Not run yet",
+            0: "No issues found",
+            1: "Notable issues found",
+            2: "Warning issues found",
+            3: "Error issues found",
+        }
+
+        def __init__(self):
+            self.severity, self.timestamp = None, None
+
+        def add(self, key, severity, quantity, search=""):
+            self[key] = {
+                "severity": severity if quantity > 0 else 0,
+                "quantity": quantity,
+                "search": search,
+            }
+
+        def done(self):
+            self.severity = max(i["severity"] for i in self.values())
+            self.timestamp = util.Datetime.now()
+
+        def __str__(self):
+            return f"{self.SEVERITY_MESSAGES[self.severity]} on {self.timestamp}"
+
+        #: Workaround for HTML template only
+        def severity_class(self):
+            return f"mbd-severity{self.severity}"
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.report = self.Report()
+
     class Instance:
+        class Status(enum.Enum):
+            MISSING = enum.auto()      # Expected instance not there
+            EXISTS = enum.auto()
+            ACTIVE = enum.auto()
+            CHANGED = enum.auto()      # Changed inactive status instance
+            FAILED = enum.auto()       # Failed (check failed) inactive status instance
+            DEACTIVATED = enum.auto()  # Deactivated (presumably on purpose by user) status instance
+
+        #: Report instances for these statuses with given severity
+        REPORT_STATUS = {
+            Status.MISSING: 2,
+            Status.CHANGED: 2,
+            Status.FAILED: 3,
+            Status.DEACTIVATED: 1,
+        }
+
         def diff(self):
             """Overload/expand this for additional custom diffs"""
             diff = {
@@ -1425,7 +1476,22 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
                         util.log_exception(LOG, f"PCA failed on {self.obj}", e)
 
             self.info["diff"] = self.diff()
-            self.info["status"] = "missing" if self.obj is None else "exists" if not self.is_status_model else "active" if self.obj.mbd_is_active() else "deactivated"
+
+            if self.obj is None:
+                status = self.Status.MISSING
+            elif not self.is_status_model:
+                status = self.Status.EXISTS
+            elif self.obj.mbd_is_active():
+                status = self.Status.ACTIVE
+            elif self.obj.mbd_is_changed():
+                status = self.Status.CHANGED
+            elif self.obj.mbd_is_reactivate():
+                status = self.Status.FAILED
+            else:
+                status = self.Status.DEACTIVATED
+            self.info["status"] = status.name
+            self.info["status_severity"] = self.REPORT_STATUS.get(status, 0)
+
             if self.obj is not None and not self.model.__name__.endswith("Option"):
                 # Help for HTML template only
                 self.info["change_instance_url"] = f"admin:mini_buildd_{self.model.__name__.lower()}_change"
@@ -1754,30 +1820,13 @@ class Setup(_Admin, _Confirm, _Maintenance, Call):
             Setup.Instance(self, util.models().Remote, {}, {}, http=ep)
 
         # Report
-        self.result["report"]["setup"] = {
-            "quantity": sum((1 for i in self.result["instances"] if i["diff"]["setup"]["diff"])),
-            "desc": "differences from",
-            "search": "\"setup diff\"",
-            "severity": "warning",
-        }
-        self.result["report"]["model"] = {
-            "quantity": sum((1 for i in self.result["instances"] if i["diff"]["model"]["diff"])),
-            "desc": "differences from",
-            "search": "\"model diff\"",
-            "severity": "notice",
-        }
-        self.result["report"]["deactivated"] = {
-            "quantity": sum((1 for i in self.result["instances"] if i["status"] == "deactivated")),
-            "desc": "",
-            "search": "deactivated",
-            "severity": "warning",
-        }
-        self.result["report"]["missing"] = {
-            "quantity": sum((1 for i in self.result["instances"] if i["status"] == "missing")),
-            "desc": "",
-            "search": "missing",
-            "severity": "warning",
-        }
+        self.report.add("Total instances traversed", 0, len(self.result["instances"]))
+        self.report.add("Differences from setup", 2, sum((1 for i in self.result["instances"] if i["diff"]["setup"]["diff"])), '"setup diff"')
+        self.report.add("Differences from model defaults", 1, sum((1 for i in self.result["instances"] if i["diff"]["model"]["diff"])), '"model diff"')
+        for status, severity in self.Instance.REPORT_STATUS.items():
+            self.report.add(f"{status.name.capitalize()} instances", severity, sum((1 for i in self.result["instances"] if i["status"] == status.name)), status.name)
+
+        self.report.done()
 
     def _run(self):
         self.__run()
