@@ -7,11 +7,6 @@ import abc
 import logging
 import logging.handlers
 import warnings
-import subprocess
-import re
-import syslog
-import socket
-import getpass
 
 import argcomplete
 
@@ -188,42 +183,3 @@ class CLI():
         except BaseException as e:
             util.log_exception(LOG, f"{self.prog} failed (try '--log-level DEBUG')", e, level=logging.ERROR)
             sys.exit(1)
-
-
-def auth_log(msg):
-    """
-    Uff -- dirty hack to get an 'auth' log including the ssh fingerprint
-
-    Needed (for now) by ``m-b-ssh-uploader-command``, ``m-b-ssh-client-command``.
-
-    Needs sshd on loglevel=VERBOSE, and the user needs access to
-    auth.log (i.e., add user to group 'adm' in standard Debian).
-    """
-    def getpppid():
-        """Get grandparent PID"""
-        return subprocess.check_output(f"/bin/ps -p {os.getppid()} -oppid=", shell=True).strip()
-
-    def get_last_matching_line(file_name, regex):
-        result = None
-        with util.fopen(file_name) as f:
-            for line in f:
-                if re.match(regex, line):
-                    result = line
-        return result
-
-    def get_fingerprint():
-        try:
-            line = get_last_matching_line("/var/log/auth.log", rf"^.*sshd\[{getpppid()}\]: Found matching .* key: .*")
-            fp = line.rpartition(" ")[2].strip()
-        except BaseException:
-            fp = "NO_FINGERPRINT_FOUND"
-        return fp
-
-    command = os.environ.get("SSH_ORIGINAL_COMMAND", "NO_COMMAND_FOUND")
-    ip = os.environ.get("SSH_CONNECTION", "NO_IP_FOUND").partition(" ")[0]
-    try:
-        host = socket.gethostbyaddr(ip)[0]
-    except BaseException:
-        host = ip
-
-    syslog.syslog(syslog.LOG_NOTICE, f"{msg}: [{getpass.getuser()}] {get_fingerprint()}@{host} \"{command}\"")
