@@ -3,7 +3,7 @@ import logging
 
 import django.conf
 
-from mini_buildd import config, util, gnupg, threads, ftpd, packager, builder, events, cron, models
+from mini_buildd import config, util, gnupg, threads, ftpd, packager, builder, events, cron, api, models
 
 LOG = logging.getLogger(__name__)
 
@@ -70,14 +70,7 @@ class Daemon(threads.EventThread, metaclass=util.Singleton):
         self.gnupg = self.model.mbd_gnupg()
         self.public_key_cache = gnupg.PublicKeyCache()
 
-        #: Dict of functions to acquire possible attention strings (HTML support in 'main_menu_item.html' include).
-        self.attention = {
-            "events": "",   # No use case (yet)
-            "builds": "",   # No use case (yet)
-            "repositories": models.Source.mbd_attention,
-            "builders": lambda: models.Chroot.mbd_attention() + models.Remote.mbd_attention(),
-            "crontab": self.crontab.attention,
-        }
+        self.report = api.Setup.Report()
 
     def handshake_message(self):
         return self.gnupg.gpgme_sign(config.HANDSHAKE_MESSAGE)
@@ -114,6 +107,12 @@ class Daemon(threads.EventThread, metaclass=util.Singleton):
                 self.public_key_cache.close()
                 Daemon.destroy()
 
+    def mbd_inspect(self):
+        util.models().Daemon.Admin.mbd_check(util.models().get_daemon(), force=True)
+        inspect = api.Setup.setup_inspect()
+        inspect._run()  # pylint: disable=protected-access  # This should not be a "maintenance" call
+        self.report = inspect.report
+
 
 class Stopped():
     def __init__(self):
@@ -124,4 +123,4 @@ class Stopped():
 
     def __exit__(self, type_, value_, tb_):
         if self.start:
-            util.daemon().mbd_start()
+            util.attempt(util.daemon().mbd_start)
